@@ -15,6 +15,7 @@ except ModuleNotFoundError:
 
 
 class Response(requests.Response):
+    """This object contains a server’s response to an HTTP request."""
     def __init__(self):
         super().__init__()
         self.req: Optional[Request] = None
@@ -22,5 +23,6 @@ class Response(requests.Response):
         self.session: Optional[requests.Session] = None
 
     def select(self, selector: str, **kw) -> List[bs4.element.Tag]:
+        """Perform a CSS selection operation on the HTML element."""
         soup = BeautifulSoup(self.text, parser)
         return soup.select(selector, **kw)
